@@ -1,4 +1,4 @@
-# $Id: IO_Poll.pm 1903 2006-03-20 04:44:08Z rcaputo $
+# $Id: IO_Poll.pm 2089 2006-09-02 05:53:27Z rcaputo $
 
 # IO::Poll event loop bridge for POE::Kernel.  The theory is that this
 # will be faster for large scale applications.  This file is
@@ -8,7 +8,7 @@
 package POE::Loop::IO_Poll;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1903 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2089 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # Include common signal handling.
 use POE::Loop::PerlSignals;
@@ -67,7 +67,8 @@ sub loop_initialize {
 }
 
 sub loop_finalize {
-  # does nothing
+  my $self = shift;
+  $self->loop_ignore_all_signals();
 }
 
 #------------------------------------------------------------------------------
@@ -297,6 +298,7 @@ sub loop_do_timeslice {
 
         # This is where they're gathered.
 
+        my (@rd_ready, @wr_ready, @ex_ready);
         while (@filenos) {
           my ($fd, $got_mask) = splice(@filenos, 0, 2);
           next unless $got_mask;
@@ -310,7 +312,7 @@ sub loop_do_timeslice {
               POE::Kernel::_warn "<fh> enqueuing read for fileno $fd";
             }
 
-            $self->_data_handle_enqueue_ready(MODE_RD, $fd);
+            push @rd_ready, $fd;
           }
 
           if ( $watch_mask & POLLWRNORM and
@@ -320,7 +322,7 @@ sub loop_do_timeslice {
               POE::Kernel::_warn "<fh> enqueuing write for fileno $fd";
             }
 
-            $self->_data_handle_enqueue_ready(MODE_WR, $fd);
+            push @wr_ready, $fd;
           }
 
           if ( $watch_mask & POLLRDBAND and
@@ -330,9 +332,13 @@ sub loop_do_timeslice {
               POE::Kernel::_warn "<fh> enqueuing expedite for fileno $fd";
             }
 
-            $self->_data_handle_enqueue_ready(MODE_EX, $fd);
+            push @ex_ready, $fd;
           }
         }
+
+        @rd_ready and $self->_data_handle_enqueue_ready(MODE_RD, @rd_ready);
+        @wr_ready and $self->_data_handle_enqueue_ready(MODE_WR, @wr_ready);
+        @ex_ready and $self->_data_handle_enqueue_ready(MODE_EX, @ex_ready);
       }
     }
 
