@@ -1,11 +1,11 @@
-# $Id: NFA.pm 1946 2006-04-29 22:43:06Z rcaputo $
+# $Id: NFA.pm 2116 2006-09-08 04:45:45Z rcaputo $
 
 package POE::NFA;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1946 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2116 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw(carp croak);
 
@@ -41,7 +41,8 @@ sub STACK_EVENT         () { 1 }
 #------------------------------------------------------------------------------
 
 # Shorthand for defining a trace constant.
-sub define_trace {
+
+sub _define_trace {
   no strict 'refs';
   foreach my $name (@_) {
     next if defined *{"TRACE_$name"}{CODE};
@@ -90,7 +91,7 @@ BEGIN {
     }
   };
 
-  define_trace("DESTROY");
+  _define_trace("DESTROY");
 }
 
 #------------------------------------------------------------------------------
@@ -353,7 +354,7 @@ sub _invoke_state {
     $handler = $self->[SELF_CURRENT]->{+EN_DEFAULT};
 
     # Transform the parameters for _default.  ARG1 and beyond are
-		# copied so they can't be altered at a distance.
+    # copied so they can't be altered at a distance.
     $args  = [ $event, [@$args] ];
     $event = EN_DEFAULT;
   }
