@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: Makefile-5005.pm 1891 2006-03-18 23:45:26Z rcaputo $
+# $Id: Makefile-5005.pm 2031 2006-08-07 04:15:20Z rcaputo $
 
 use strict;
 
@@ -89,19 +89,6 @@ system($^X, "mylib/gen-tests.perl") and die "couldn't generate tests: $!";
 
 ### Generate Makefile.PL.
 
-# sub MY::postamble {
-#   return ExtUtils::AutoInstall::postamble() .
-#     <<EOF;
-# reportupload: poe_report.xml
-# \cI$^X mylib/reportupload.pl
-# 
-# uploadreport: poe_report.xml
-# \cI$^X mylib/reportupload.pl
-# 
-# testreport: poe_report.xml
-# 
-# poe_report.xml: Makefile
-# \cI$^X mylib/testreport.pl
 sub MY::postamble {
   return <<EOF;
 
@@ -150,6 +137,7 @@ WriteMakefile(
   PL_FILES       => { },
   NO_META        => 1,
   PREREQ_PM      => { CORE_REQUIREMENTS },
+  PM_FILTER      => "$^X mylib/preprocessor.perl",
 );
 
 1;
